@@ -3,11 +3,11 @@ from email.message import EmailMessage
 from email.mime.text import MIMEText
 import re
 from .exceptions import UnsupportedEmailProvider
-from typing import Union, NoReturn
+from typing import Union
 
 
 def send_mail(email_sender: str, password: str, subject: str,
-              message: Union[str, MIMEText], email_receiver: str) -> NoReturn:
+              message: Union[str, MIMEText], email_receiver: str) -> None:
     """Send an Email"""
 
     domain = re.search("(?<=@)[^.]+(?=\\.)", email_sender)
@@ -39,7 +39,7 @@ def send_mail(email_sender: str, password: str, subject: str,
 
 
 def send_hmail(email_sender: str, password: str, subject: str,
-               html_code: str, email_receiver: str) -> NoReturn:
+               html_code: str, email_receiver: str) -> None:
     """Send an Email with HTML code"""
 
     message = MIMEText(html_code, "html")
